CREATE SCHEMA Umfeldmessstelle

-- Historie:
--
-- 03.09.2003 - 1.003 (1.008)
-- Korrektur der historischen Gltigkeitsdaten
--
-- 31.05.2002 - 1.002 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 17.12.2000 - 1.001 (1.002)
-- Verlegung der oertlichen_Zuordnung in das Straennetz
--
-- Verlegung der verwaltungstechn_Zuordnung in die Administration
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Umfeldmessstelle (
   Umfeldmessstelle_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Umfeldmessstelle_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Nummer
      INTEGER NOT NULL,
   hat_verwaltungstechn_Zuordnung
      INTEGER NOT NULL REFERENCES verwaltungstechn_Zuordng_UM,
   hat_oertliche_Zuordnung
      INTEGER NOT NULL REFERENCES oertliche_Zuordnung_UM,
   hat_Erfassungsmodalitaeten
      INTEGER NOT NULL REFERENCES Erfassungsmodalitaeten
)

CREATE TABLE Umfmessst__Messeinr_Schadstimm (
   Umfeldmessstelle
      INTEGER NOT NULL REFERENCES Umfeldmessstelle,
   Messeinricht_Schadstoffimmiss
      VARCHAR(99) NOT NULL
)

CREATE TABLE Umfmessst__hat_Messdaten (
   Umfeldmessstelle
      INTEGER NOT NULL REFERENCES Umfeldmessstelle,
   Messdaten
      INTEGER NOT NULL REFERENCES Messdaten
)

CREATE TABLE Umfmessst__hat_Det_Umfdatenerf (
   Umfeldmessstelle
      INTEGER NOT NULL REFERENCES Umfeldmessstelle,
   Detektoren_Umfelddatenerfassg
      INTEGER NOT NULL REFERENCES Detektoren_Umfelddatenerfassg
)

CREATE TABLE VBA_Wetterstation (
   VBA_Wetterstation_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (VBA_Wetterstation_ID) REFERENCES Umfeldmessstelle,
   Nutzungsart
      VARCHAR(50)
)

CREATE TABLE SWIS_GMA_Messstelle (
   SWIS_GMA_Messstelle_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (SWIS_GMA_Messstelle_ID) REFERENCES Umfeldmessstelle,
   Nutzungsart
      VARCHAR(30)
)

CREATE TABLE Messdaten (
   Messdaten_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Messdaten__hat_Umfang_Umfdaten (
   Messdaten
      INTEGER NOT NULL REFERENCES Messdaten,
   Umfang_Umfelddaten
      INTEGER NOT NULL REFERENCES Umfang_Umfelddaten
)

CREATE TABLE Messdaten__hat_Zaehlintervlge (
   Messdaten
      INTEGER NOT NULL REFERENCES Messdaten,
   Zaehlintervalllaenge
      INTEGER NOT NULL REFERENCES Zaehlintervalllaenge
)

CREATE TABLE Erfassungsmodalitaeten (
   Erfassungsmodalitaeten_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Erfassungsbereich
      INTEGER NOT NULL REFERENCES Erfassungsbereich,
   hat_Zaehlzeitraum
      INTEGER NOT NULL REFERENCES Zaehlzeitraum
)

CREATE TABLE Lage_der_Sensoren (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Lage_der_Sensoren VALUES (1,'in der Fahrbahn')
INSERT INTO Lage_der_Sensoren VALUES (2,'neben der Fahrbahn')
INSERT INTO Lage_der_Sensoren VALUES (3,'in und neben der Fahrbahn')
INSERT INTO Lage_der_Sensoren VALUES (4,'auerhalb des Straenbereichs')

CREATE TABLE Erfassungsbereich (
   Erfassungsbereich_ID
      INTEGER NOT NULL PRIMARY KEY,
   von_Netzknoten
      INTEGER NOT NULL,
   nach_Netzknoten
      INTEGER NOT NULL,
   Lage_der_Sensoren
      INTEGER NOT NULL REFERENCES Lage_der_Sensoren
)

CREATE TABLE Zaehlzeitraum (
   Zaehlzeitraum_ID
      INTEGER NOT NULL PRIMARY KEY,
   Beginn_Erfassung
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Beginn_Erfassung LIKE '__.__.____' ),
   Ende_Erfassung
      CHAR(10), -- Datum
   CHECK ( Ende_Erfassung LIKE '__.__.____' )
)

CREATE TABLE Detektoren_Umfelddatenerfassg (
   Detektoren_Umfelddatenerf_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Detekt_Umfdaterf__zugeh_EAKs (
   Detektoren_Umfelddatenerfassg
      INTEGER NOT NULL REFERENCES Detektoren_Umfelddatenerfassg,
   zugehoerige_EAKs
      VARCHAR(99) NOT NULL
)

CREATE TABLE Detekt_Umfdaterf__Einsatzzeit (
   Detektoren_Umfelddatenerfassg
      INTEGER NOT NULL REFERENCES Detektoren_Umfelddatenerfassg,
   Einsatzzeit
      VARCHAR(50) NOT NULL
)

CREATE TABLE Detekt_Umfdaterf__Betriebszeit (
   Detektoren_Umfelddatenerfassg
      INTEGER NOT NULL REFERENCES Detektoren_Umfelddatenerfassg,
   Betriebszeit
      VARCHAR(50) NOT NULL
)

CREATE TABLE Umfang_Umfelddaten (
   Umfang_Umfelddaten_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Umf_Umfelddat__erfasste_Daten (
   Umfang_Umfelddaten
      INTEGER NOT NULL REFERENCES Umfang_Umfelddaten,
   erfasste_Daten
      INTEGER NOT NULL
)

CREATE TABLE Umf_Umfelddat__Erm_Schadstimm (
   Umfang_Umfelddaten
      INTEGER NOT NULL REFERENCES Umfang_Umfelddaten,
   Ermittlung_Schadstoffimmiss
      VARCHAR(99) NOT NULL
)

CREATE TABLE Umf_Umfelddat__hat_Wittergsdat (
   Umfang_Umfelddaten
      INTEGER NOT NULL REFERENCES Umfang_Umfelddaten,
   Witterungsdaten
      INTEGER NOT NULL REFERENCES Witterungsdaten
)

CREATE TABLE Umf_Umfelddat__hat_Umfelddaten (
   Umfang_Umfelddaten
      INTEGER NOT NULL REFERENCES Umfang_Umfelddaten,
   Umfelddaten
      INTEGER NOT NULL REFERENCES Umfelddaten
)

CREATE TABLE Umf_Umfelddat__hat_witb_Strzst (
   Umfang_Umfelddaten
      INTEGER NOT NULL REFERENCES Umfang_Umfelddaten,
   witterungsbed_Strassenzustand
      INTEGER NOT NULL REFERENCES witterungsbed_Strassenzustand
)

CREATE TABLE Witterungsdaten (
   Witterungsdaten_ID
      INTEGER NOT NULL PRIMARY KEY,
   Luftdruck
      INTEGER, -- Hektopascal
   CHECK ( ( Luftdruck >= 800 ) AND ( Luftdruck <= 1200 ) ),
   relative_Luftfeuchte
      REAL, -- Prozent
   Lufttemperatur
      REAL, -- Grad_Celsius
   CHECK ( Lufttemperatur>=0 ),
   Windrichtung
      INTEGER, -- Grad
   CHECK ( ( Windrichtung >= 0 ) AND ( Windrichtung <= 359 ) ),
   mittlere_Windgeschwindigkeit
      REAL, -- Meter_pro_Sekunde
   CHECK ( mittlere_Windgeschwindigkeit>=0 ),
   CHECK ( mittlere_Windgeschwindigkeit>=0 ),
   Spitzenwindgeschwindigkeit
      REAL, -- Meter_pro_Sekunde
   CHECK ( Spitzenwindgeschwindigkeit>=0 ),
   CHECK ( Spitzenwindgeschwindigkeit>=0 ),
   Niederschlagsart
      INTEGER,
   Niederschlagsintensitaet
      REAL, -- Millimeter_pro_Stunde
   CHECK ( Niederschlagsintensitaet>=0 ),
   CHECK ( Niederschlagsintensitaet>=0 ),
   Niederschlagsmenge
      REAL, -- Millimeter
   CHECK ( Niederschlagsmenge>=0 ),
   CHECK ( Niederschlagsintensitaet<=200 ),
   CHECK ( Spitzenwindgeschwindigkeit<=60 ),
   CHECK ( mittlere_Windgeschwindigkeit<=60 ),
   CHECK ( ( Lufttemperatur >= -30 ) AND ( Lufttemperatur <= 60 ) ),
   CHECK ( ( relative_Luftfeuchte >= 10 ) AND ( relative_Luftfeuchte <= 100 ) )
)

CREATE TABLE Umfelddaten (
   Umfelddaten_ID
      INTEGER NOT NULL PRIMARY KEY,
   Sichtweite
      REAL, -- Meter
   Helligkeit
      INTEGER, -- Lux
   CHECK ( Helligkeit>=0 ),
   CHECK ( ( Helligkeit >= 0 ) AND ( Helligkeit <= 60000 ) ),
   CHECK ( ( Sichtweite >= 10 ) AND ( Sichtweite <= 1000 ) )
)

CREATE TABLE witterungsbed_Strassenzustand (
   witterungsbed_Strassenzustd_ID
      INTEGER NOT NULL PRIMARY KEY,
   Zustand_Fahrbahnoberflaeche
      INTEGER,
   Wasserfilmdicke
      REAL, -- Millimeter
   CHECK ( Wasserfilmdicke>=0 ),
   Fahrbahnoberflaechentemperatur
      REAL, -- Grad_Celsius
   CHECK ( Fahrbahnoberflaechentemperatur>=0 ),
   Taupunkttemperatur
      REAL, -- Grad_Celsius
   CHECK ( Taupunkttemperatur>=0 ),
   Gefrierpunkttemperatur
      REAL, -- Grad_Celsius
   CHECK ( Gefrierpunkttemperatur>=0 ),
   Restsalzgehalt
      REAL, -- Prozent
   Schneehoehe
      REAL, -- Zentimeter
   CHECK ( Schneehoehe>=0 ),
   Bodentemperatur_in_Tiefe_1
      REAL, -- Grad_Celsius
   CHECK ( Bodentemperatur_in_Tiefe_1>=0 ),
   Bodentemperatur_in_Tiefe_2
      REAL, -- Grad_Celsius
   CHECK ( Bodentemperatur_in_Tiefe_2>=0 ),
   Bodentemperatur_in_Tiefe_3
      REAL, -- Grad_Celsius
   CHECK ( Bodentemperatur_in_Tiefe_3>=0 ),
   CHECK ( ( Bodentemperatur_in_Tiefe_3 >= -30 ) AND ( Bodentemperatur_in_Tiefe_3 <= 80 ) ),
   CHECK ( ( Bodentemperatur_in_Tiefe_2 >= -30 ) AND ( Bodentemperatur_in_Tiefe_2 <= 80 ) ),
   CHECK ( ( Bodentemperatur_in_Tiefe_1 >= -30 ) AND ( Bodentemperatur_in_Tiefe_1 <= 80 ) ),
   CHECK ( ( Schneehoehe >= 0 ) AND ( Schneehoehe <= 200 ) ),
   CHECK ( ( Restsalzgehalt >= 0 ) AND ( Restsalzgehalt <= 100 ) ),
   CHECK ( ( Gefrierpunkttemperatur >= -30 ) AND ( Gefrierpunkttemperatur <= 0 ) ),
   CHECK ( ( Taupunkttemperatur >= -30 ) AND ( Taupunkttemperatur <= 60 ) ),
   CHECK ( ( Fahrbahnoberflaechentemperatur >= -30 ) AND ( Fahrbahnoberflaechentemperatur <= 80 ) )
)

CREATE TABLE verwaltungstechn_Zuordng_UM (
   verwaltungstechn_Zuordng_UM_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (verwaltungstechn_Zuordng_UM_ID) REFERENCES Administration.verwaltungstechn_Zuordnung
)

CREATE TABLE oertliche_Zuordnung_UM (
   oertliche_Zuordnung_UM_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (oertliche_Zuordnung_UM_ID) REFERENCES Strassennetz.oertliche_Zuordnung
)

CREATE TABLE Zaehlintervalllaenge (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Zaehlintervalllaenge VALUES (1,'60 min')
INSERT INTO Zaehlintervalllaenge VALUES (2,'30 min')
INSERT INTO Zaehlintervalllaenge VALUES (3,'15 min')
INSERT INTO Zaehlintervalllaenge VALUES (4,'1 min')
INSERT INTO Zaehlintervalllaenge VALUES (5,'5 min')


