CREATE SCHEMA Allgemeine_Objekte

-- Historie:
--
-- 03.09.2003 - 1.005 (1.008)
-- Ergnzung der Whrungsangabe, Vorzeichen, Objekt-Id, Foto und Sensor
--
-- 31.05.2002 - 1.004 (1.007)
-- Erweiterung der Wertebereiche von Meter, Kilometer und Jahr
--
-- 12.09.2001 - 1.003 (1.004)
-- Typen Waehrung, Kubikzentimeter, Promille, Anzahl_einstellig ergnzt
--
-- 17.12.2000 - 1.002 (1.002)
-- Verlegung der oertlichen_Zuordnung und
-- der nicht_nach_ASB_klass_Strasse in das Straennetz
--
-- Verlegung der verwaltungstechn_Zuordnung in die Administration
--
-- 29.10.2000 - 1.001 (1.001)
-- passive Versionierung durch Integration der
-- Schemata allgemeine Geometrieobjekte und Grunderwerb
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Wochentag (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(10) NOT NULL
)

INSERT INTO Wochentag VALUES (1,'Sonntag')
INSERT INTO Wochentag VALUES (2,'Montag')
INSERT INTO Wochentag VALUES (3,'Dienstag')
INSERT INTO Wochentag VALUES (4,'Mittwoch')
INSERT INTO Wochentag VALUES (5,'Donnerstag')
INSERT INTO Wochentag VALUES (6,'Freitag')
INSERT INTO Wochentag VALUES (7,'Samstag')

CREATE TABLE Waehrungsangabe (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Waehrungsangabe VALUES( 1, 'EURO' )
INSERT INTO Waehrungsangabe VALUES( 2, 'DM' )

CREATE TABLE Startdatum (
   Startdatum_ID
      INTEGER NOT NULL PRIMARY KEY,
   Jahr
      INTEGER,
   Monat_im_Jahr
      INTEGER,
   Woche_im_Jahr
      INTEGER,
   Tag_im_Monat
      INTEGER,
   vorwaerts_oder_rueckwaerts
      INTEGER REFERENCES Logical_Types.Boolean,
   Woche_im_Monat
      INTEGER,
   Tag_in_der_Woche
      INTEGER,
   Stunde_am_Tag
      INTEGER,
   Minute_in_der_Stunde
      INTEGER,
   Sekunde_in_der_Minute
      INTEGER,
   CHECK ( ( Monat_im_Jahr IS NULL ) OR ( Woche_im_Jahr IS NULL ) )
)

CREATE TABLE Dauer (
   Dauer_ID
      INTEGER NOT NULL PRIMARY KEY,
   Jahre
      INTEGER,
   Monate
      INTEGER,
   Wochen
      INTEGER,
   Tage
      INTEGER,
   Stunden
      INTEGER,
   Minuten
      INTEGER,
   Sekunden
      INTEGER
)

CREATE TABLE Operator (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Operator VALUES ('+','Vereinigung')
INSERT INTO Operator VALUES ('*','Durchschnitt')
INSERT INTO Operator VALUES ('-','Differenz')

CREATE TABLE Zeitraum (
   Zeitraum_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_ersten_Zeitraum
      INTEGER REFERENCES Zeitraum,
   hat_zweiten_Zeitraum
      INTEGER REFERENCES Zeitraum,
   hat_Operator
      CHAR(1) REFERENCES Operator,
   hat_Startdatum
      INTEGER REFERENCES Startdatum,
   hat_Dauer
      INTEGER REFERENCES Dauer,
   FOREIGN KEY (Zeitraum_ID) REFERENCES Historisierung.historisches_Objekt,
   gueltig_von
      CHAR(10), -- Datum
   CHECK ( gueltig_von LIKE '__.__.____' ),
   gueltig_bis
      CHAR(10), -- Datum
   CHECK ( gueltig_bis LIKE '__.__.____' ),
   Art_Zeitraum
      INTEGER NOT NULL REFERENCES Art_Zeitraum
)

CREATE TABLE Art_Zeitraum (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(18) NOT NULL
)

INSERT INTO Art_Zeitraum VALUES ( 26003, 'einfacher_Zeitraum' )
INSERT INTO Art_Zeitraum VALUES ( 26006, 'komplexer_Zeitraum' )

CREATE TABLE Vorzeichen (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Vorzeichen VALUES ('+','Summe')
INSERT INTO Vorzeichen VALUES ('-','Differenz')

CREATE TABLE Objekt_ID (
   Objekt_ID_ID
      INTEGER NOT NULL PRIMARY KEY,
   ID
      VARCHAR(255) NOT NULL,
   Namensraum_Verfahren
      VARCHAR(255) NOT NULL
)

CREATE TABLE geometrische_Auspraegung (
   geometrische_Auspraegung_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE geom_Auspr__hat_Auspr_Punkt (
   geometrische_Auspraegung
      INTEGER NOT NULL REFERENCES geometrische_Auspraegung,
   geometrische_Auspraegung_Punkt
      INTEGER NOT NULL REFERENCES geometrische_Auspraegung_Punkt
)

CREATE TABLE geometrische_Auspraegung__hat_Auspraegung_Linie (
   geometrische_Auspraegung
      INTEGER NOT NULL REFERENCES geometrische_Auspraegung,
   geometrische_Auspraegung_Linie
      INTEGER NOT NULL REFERENCES geometrische_Auspraegung_Linie
)

CREATE TABLE geometrische_Auspraegung__hat_Auspraegung_Flaeche (
   geometrische_Auspraegung
      INTEGER NOT NULL REFERENCES geometrische_Auspraegung,
   geometr_Auspraegung_Flaeche
      INTEGER NOT NULL REFERENCES geometr_Auspraegung_Flaeche
)

CREATE TABLE geometrische_Auspraegung_Punkt (
   geometr_Auspraegung_Punkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (geometr_Auspraegung_Punkt_ID) REFERENCES Geometrieschema.Punktobjekt_Modell
)

CREATE TABLE geometrische_Auspraegung_Linie (
   geometr_Auspraegung_Linie_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (geometr_Auspraegung_Linie_ID) REFERENCES Geometrieschema.Linienobjekt_Modell
)

CREATE TABLE geometr_Auspraegung_Flaeche (
   geometr_Auspraegung_Flaeche_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (geometr_Auspraegung_Flaeche_ID) REFERENCES Geometrieschema.Flaechenobjekt_Modell
)

CREATE TABLE Sensor (
   Sensor_ID
      INTEGER NOT NULL PRIMARY KEY,
   Wirkungsrichtung_horizontal
      REAL, -- Winkel
   Wirkungsrichtung_vertikal
      REAL, -- Winkel
   Art
      INTEGER NOT NULL REFERENCES Art_Sensor,
   Typbezeichnung
      VARCHAR(255),
   Hoehe_ueber_Boden
      REAL, -- Meter
   hat_Sensorstandort
      INTEGER NOT NULL REFERENCES Sensorstandort
)

CREATE TABLE Art_Sensor (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(30) NOT NULL
)

INSERT INTO Art_Sensor VALUES (1,'Fotokamera')
INSERT INTO Art_Sensor VALUES (2,'Videokamera')
INSERT INTO Art_Sensor VALUES (3,'Mikrofon')
INSERT INTO Art_Sensor VALUES (4,'Wrmebildkamera')

CREATE TABLE Sensorstandort (
   Sensorstandort_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Erfassungsqualitaet
      VARCHAR(255) NOT NULL, -- Erfassungsqualitaet
   hat_Sensorstandpunkt
      INTEGER REFERENCES Sensorstandpunkt,
   hat_Sensorstandlinie
      INTEGER REFERENCES Sensorstandlinie,
   CHECK ( ( hat_Sensorstandpunkt IS NOT NULL AND hat_Sensorstandlinie IS NULL ) OR ( hat_Sensorstandpunkt IS NULL AND hat_Sensorstandlinie IS NOT NULL ) )
)

CREATE TABLE Sensorstandpunkt (
   Sensorstandpunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Sensorstandpunkt_ID) REFERENCES Geometrieschema.Punktobjekt_Modell
)

CREATE TABLE Sensorstandlinie (
   Sensorstandlinie_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Sensorstandlinie_ID) REFERENCES Geometrieschema.Linienobjekt_Modell
)

CREATE TABLE Foto (
   Foto_ID
      INTEGER NOT NULL PRIMARY KEY,
   erstellt_von
      VARCHAR(255),
   physikalische_Aufloesung
      INTEGER, -- dpi
   Farbspektrum
      INTEGER, -- Farbtiefe
   Datei
      VARCHAR(255),
   inhaltliche_Beschreibung
      VARCHAR(255),
   Startdatum
      INTEGER NOT NULL REFERENCES Startdatum,
   verwendetes_Verfahren
      INTEGER REFERENCES fotografisches_Verfahren,
   Aufbewahrungsort_Medium_analog
      VARCHAR(255),
   hat_Fotostandpunkt
      INTEGER REFERENCES Fotostandpunkt
)

CREATE TABLE fotografisches_Verfahren (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(60) NOT NULL
)

INSERT INTO fotografisches_Verfahren VALUES (1,'Digitalkamera')
INSERT INTO fotografisches_Verfahren VALUES (2,'Analogkamera, scannen des Papierabzuges')
INSERT INTO fotografisches_Verfahren VALUES (3,'Analogkamera, scannen des Dia-Positives')

CREATE TABLE Fotostandpunkt (
   Fotostandpunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Fotostandpunkt_ID) REFERENCES Sensor
)


CREATE SCHEMA Logical_Types


CREATE TABLE Boolean (
   Boolean_ID
      INTEGER NOT NULL PRIMARY KEY,
   Boolean
      VARCHAR (5)
) 

INSERT INTO Boolean VALUES ( 0 , 'FALSE' ) 
INSERT INTO Boolean VALUES ( 1 , 'TRUE' ) 

