CREATE SCHEMA Kostenberechnung

-- Historie:
-- 
-- 03.09.2003 - 1.000 (1.008)
-- Schema Kostenberechnung in den OKSTRA aufgenommen


CREATE TABLE Kostra_Projekt (
   Kostra_Projekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Projektkennzeichnung
      INTEGER NOT NULL REFERENCES Projektkennzeichnung_Kostra,
   hat_Kostendaten
      INTEGER NOT NULL REFERENCES Kostendaten,
   hat_Regionaltext_Freitext_Kat
      INTEGER NOT NULL REFERENCES Regionaltext_Freitext_Katalog,
   hat_HOAI_Daten
      INTEGER REFERENCES HOAI_Daten,
   hat_Formblaetter
      INTEGER NOT NULL REFERENCES Formblaetter
)

CREATE TABLE Projektkennzeichnung_Kostra (
   Projektkennzeichnung_Kostra_ID
      INTEGER NOT NULL PRIMARY KEY,
   VKE_Nummer_der_Verkehrseinheit
      INTEGER, -- Anzahl_zweistellig
   CHECK ( ( VKE_Nummer_der_Verkehrseinheit >= 0 ) AND ( VKE_Nummer_der_Verkehrseinheit <= 99 ) ),
   VKE_Laenge
      REAL NOT NULL, -- Kilometer
   Datum_des_Standes
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Datum_des_Standes LIKE '__.__.____' ),
   vollstaendige_Projektnummer
      VARCHAR(100) NOT NULL,
   Entwurfsart
      INTEGER NOT NULL REFERENCES Entwurfsart_AKS,
   Stand_der_Fortschreibung
      INTEGER NOT NULL REFERENCES Stand_der_Fortschreibung_AKS,
   Berechnungsart
      CHAR(1) NOT NULL REFERENCES Berechnungsart_AKS,
   Genauigkeit
      CHAR(1) NOT NULL REFERENCES Genauigkeit_AKS,
   hat_Land
      INTEGER REFERENCES Administration.Verwaltungsbezirk_abstrakt,
   hat_Strasse
      INTEGER REFERENCES Strassennetz.Strasse_abstrakt,
   hat_nicht_nach_ASB_klass_Str
      INTEGER REFERENCES Strassennetz.nicht_nach_ASB_klass_Strasse,
   hat_Zusatzdaten
      INTEGER NOT NULL REFERENCES Zusatzdaten_Kostra
)

CREATE TABLE Projkennz_Kostra__Traeg_d_Baum (
   Projektkennzeichnung_Kostra
      INTEGER NOT NULL REFERENCES Projektkennzeichnung_Kostra,
   Traeger_der_Baumassnahme
      VARCHAR(100) NOT NULL,
   folgt_auf_Traeger_der_Baumassnahme
      VARCHAR(100)
)

CREATE TABLE Projektkennz_Kostra__Streckenb (
   Projektkennzeichnung_Kostra
      INTEGER NOT NULL REFERENCES Projektkennzeichnung_Kostra,
   Streckenbezeichnung
      VARCHAR(100) NOT NULL,
   folgt_auf_Streckenbezeichnung
      VARCHAR(100)
)

CREATE TABLE Projkennz_Kostra__Projektbez (
   Projektkennzeichnung_Kostra
      INTEGER NOT NULL REFERENCES Projektkennzeichnung_Kostra,
   Projektbezeichnung
      VARCHAR(100) NOT NULL,
   folgt_auf_Projektbezeichnung
      VARCHAR(100)
)

CREATE TABLE Projektkennz_Kostra_Bauabschn (
   Projektkennzeichnung_Kostra
      INTEGER NOT NULL REFERENCES Projektkennzeichnung_Kostra,
   Bauabschnitt
      VARCHAR(100) NOT NULL,
   folgt_auf_Bauabschnitt
      VARCHAR(100)
)

CREATE TABLE Entwurfsart_AKS (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Entwurfsart_AKS VALUES( 1, 'Linienuntersuchung' )
INSERT INTO Entwurfsart_AKS VALUES( 2, 'Entwurf' )
INSERT INTO Entwurfsart_AKS VALUES( 3, 'Planfeststellung' )
INSERT INTO Entwurfsart_AKS VALUES( 4, 'Ausfhrung' )

CREATE TABLE Stand_der_Fortschreibung_AKS (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Stand_der_Fortschreibung_AKS VALUES( 0, 'Aufstellung' )
INSERT INTO Stand_der_Fortschreibung_AKS VALUES( 1, '1. Fortschreibung' )
INSERT INTO Stand_der_Fortschreibung_AKS VALUES( 2, '2. Fortschreibung' )
INSERT INTO Stand_der_Fortschreibung_AKS VALUES( 3, '3. Fortschreibung' )
INSERT INTO Stand_der_Fortschreibung_AKS VALUES( 4, '4. Fortschreibung' )
INSERT INTO Stand_der_Fortschreibung_AKS VALUES( 5, '5. Fortschreibung' )
INSERT INTO Stand_der_Fortschreibung_AKS VALUES( 6, '6. Fortschreibung' )
INSERT INTO Stand_der_Fortschreibung_AKS VALUES( 7, '7. Fortschreibung' )
INSERT INTO Stand_der_Fortschreibung_AKS VALUES( 8, '8. Fortschreibung' )
INSERT INTO Stand_der_Fortschreibung_AKS VALUES( 9, '9. Fortschreibung' )

CREATE TABLE Berechnungsart_AKS (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Berechnungsart_AKS VALUES( 'H', 'Hauptberechnung' )
INSERT INTO Berechnungsart_AKS VALUES( 'N', 'Nebenberechnung' )

CREATE TABLE Genauigkeit_AKS (
   Kennung
      CHAR(1) NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Genauigkeit_AKS VALUES( 'V', 'Vereinfachte Berechnung' )
INSERT INTO Genauigkeit_AKS VALUES( 'B', 'Berechnung' )
INSERT INTO Genauigkeit_AKS VALUES( 'A', 'Abrechnung' )

CREATE TABLE Zusatzdaten_Kostra (
   Zusatzdaten_Kostra_ID
      INTEGER NOT NULL PRIMARY KEY,
   Kleinleistung
      REAL NOT NULL, -- Prozent
   Waehrung
      INTEGER NOT NULL REFERENCES Allgemeine_Objekte.Waehrungsangabe,
   Mehrwertsteuersatz
      REAL NOT NULL -- Prozent
)

CREATE TABLE Kostendaten (
   Kostendaten_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Kostendaten__hat_Lose (
   Kostendaten
      INTEGER NOT NULL REFERENCES Kostendaten,
   Lose
      INTEGER NOT NULL REFERENCES Lose,
   folgt_auf_Lose
      INTEGER REFERENCES Lose
)

CREATE TABLE Kostendaten__hat_Kostenbetlgte (
   Kostendaten
      INTEGER NOT NULL REFERENCES Kostendaten,
   Kostenbeteiligte
      INTEGER NOT NULL REFERENCES Kostenbeteiligte
)

CREATE TABLE Lose (
   Lose_ID
      INTEGER NOT NULL PRIMARY KEY,
   Bezeichnung
      VARCHAR(100) NOT NULL
)

CREATE TABLE Kostenbeteiligte (
   Kostenbeteiligte_ID
      INTEGER NOT NULL PRIMARY KEY,
   Typ
      INTEGER NOT NULL REFERENCES Typ_des_Kostenbeteiligten,
   Bezeichnung
      VARCHAR(100) NOT NULL
)

CREATE TABLE Typ_des_Kostenbeteiligten (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Typ_des_Kostenbeteiligten VALUES( 1, 'Bund Straenbauhaushalt Teil 1' )
INSERT INTO Typ_des_Kostenbeteiligten VALUES( 2, 'Bund Straenbauhaushalt Teil 2' )
INSERT INTO Typ_des_Kostenbeteiligten VALUES( 3, 'Bund sonstiges' )
INSERT INTO Typ_des_Kostenbeteiligten VALUES( 4, 'Land' )
INSERT INTO Typ_des_Kostenbeteiligten VALUES( 5, 'Kreis' )
INSERT INTO Typ_des_Kostenbeteiligten VALUES( 6, 'Gemeinde' )
INSERT INTO Typ_des_Kostenbeteiligten VALUES( 7, 'Sonstige' )

CREATE TABLE Kostenbeteiligung (
   Kostenbeteiligung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Art
      INTEGER NOT NULL REFERENCES Art_der_Kostenbeteiligung,
   Wert
      REAL NOT NULL, -- Prozent
   tatsaechliche_Kosten
      REAL NOT NULL, -- Groesse
   CHECK ( tatsaechliche_Kosten >= 0 ),
   zu_Kostenbeteiligtem
      INTEGER NOT NULL REFERENCES Kostenbeteiligte,
   Teil_von_Teil_Kostendaten
      INTEGER NOT NULL REFERENCES Teil_Kostendaten,
   Teil_von_Leistungsbeschreibung
      INTEGER NOT NULL REFERENCES Leistungsbeschreibung
)

CREATE TABLE Art_der_Kostenbeteiligung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Art_der_Kostenbeteiligung VALUES( 0, 'Prozentual' )
INSERT INTO Art_der_Kostenbeteiligung VALUES( 1, 'Pauschal' )
INSERT INTO Art_der_Kostenbeteiligung VALUES( 2, 'Rest' )

CREATE TABLE Teil_Kostendaten (
   Teil_Kostendaten_ID
      INTEGER NOT NULL PRIMARY KEY,
   Hauptteilnummer
      INTEGER NOT NULL, -- Anzahl_einstellig
   CHECK ( ( Hauptteilnummer >= 0 ) AND ( Hauptteilnummer <= 9 ) ),
   Teilnummer
      INTEGER NOT NULL, -- Anzahl_zweistellig
   CHECK ( ( Teilnummer >= 0 ) AND ( Teilnummer <= 99 ) ),
   hat_Lose
      INTEGER REFERENCES Lose,
   hat_Formblatt_C
      INTEGER REFERENCES Formblatt_C,
   Teil_von_Kostendaten
      INTEGER NOT NULL REFERENCES Kostendaten
)

CREATE TABLE Teil_Kostendaten__Bezeichnung (
   Teil_Kostendaten
      INTEGER NOT NULL REFERENCES Teil_Kostendaten,
   Bezeichnung
      VARCHAR(100) NOT NULL,
   folgt_auf_Bezeichnung
      VARCHAR(100)
)

CREATE TABLE Leistungsbeschreibung (
   Leistungsbeschreibung_ID
      INTEGER NOT NULL PRIMARY KEY,
   KBK_Nummer
      INTEGER,
   Menge
      INTEGER NOT NULL,
   Einzelpreis
      REAL NOT NULL, -- Groesse
   CHECK ( Einzelpreis >= 0 ),
   Menge_zur_Preisbildung
      INTEGER NOT NULL,
   Faktor_zur_Preisbildung
      REAL NOT NULL, -- Groesse
   CHECK ( Faktor_zur_Preisbildung >= 0 ),
   errechneter_Stuetzpreis
      REAL NOT NULL, -- Groesse
   CHECK ( errechneter_Stuetzpreis >= 0 ),
   hat_Regionaltext_Freitext
      INTEGER REFERENCES Regionaltext_Freitext,
   Teil_von_Teil_Kostendaten
      INTEGER NOT NULL REFERENCES Teil_Kostendaten
)

CREATE TABLE Regionaltext_Freitext (
   Regionaltext_Freitext_ID
      INTEGER NOT NULL PRIMARY KEY,
   KBK_Nummer
      INTEGER NOT NULL,
   Masseinheit
      CHAR(4) NOT NULL,
   in_Katalog
      INTEGER NOT NULL REFERENCES Regionaltext_Freitext_Katalog
)

CREATE TABLE Regionaltext_Freitext__Text (
   Regionaltext_Freitext
      INTEGER NOT NULL REFERENCES Regionaltext_Freitext,
   Text
      VARCHAR(35) NOT NULL,
   folgt_auf_Text
      VARCHAR(35)
)

CREATE TABLE Regionaltext_Freitext_Katalog (
   Regionaltext_Freitext_Katal_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Formblatt_C (
   Formblatt_C_ID
      INTEGER NOT NULL PRIMARY KEY,
   Datum_des_Standes_bisher
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Datum_des_Standes_bisher LIKE '__.__.____' )
)

CREATE TABLE Formblatt_C__bish_Kost_n_Hptgr (
   Formblatt_C
      INTEGER NOT NULL REFERENCES Formblatt_C,
   bisherige_Kosten_nach_Hauptgr
      INTEGER NOT NULL,
   folgt_auf_bisherige_Kosten_nach_Hauptgr
      INTEGER
)

CREATE TABLE Formblaetter (
   Formblaetter_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Formblatt_A1
      INTEGER NOT NULL REFERENCES Formblatt_A1,
   hat_Formblatt_A2
      INTEGER NOT NULL REFERENCES Formblatt_A2,
   hat_Formblatt_A3
      INTEGER REFERENCES Formblatt_A3,
   hat_Formblatt_B
      INTEGER NOT NULL REFERENCES Formblatt_B,
   hat_Formblatt_S1
      INTEGER REFERENCES Formblatt_S1
)

CREATE TABLE Formblatt_A1 (
   Formblatt_A1_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Formblatt_A1__Aufgestellt (
   Formblatt_A1
      INTEGER NOT NULL REFERENCES Formblatt_A1,
   Aufgestellt
      VARCHAR(40) NOT NULL,
   folgt_auf_Aufgestellt
      VARCHAR(40)
)

CREATE TABLE Formblatt_A1__Geprueft (
   Formblatt_A1
      INTEGER NOT NULL REFERENCES Formblatt_A1,
   Geprueft
      VARCHAR(40) NOT NULL,
   folgt_auf_Geprueft
      VARCHAR(40)
)

CREATE TABLE Formblatt_A1__Genehmigt (
   Formblatt_A1
      INTEGER NOT NULL REFERENCES Formblatt_A1,
   Genehmigt
      VARCHAR(40) NOT NULL,
   folgt_auf_Genehmigt
      VARCHAR(40)
)

CREATE TABLE Formblatt_A1__Gesehen (
   Formblatt_A1
      INTEGER NOT NULL REFERENCES Formblatt_A1,
   Gesehen
      VARCHAR(40) NOT NULL,
   folgt_auf_Gesehen
      VARCHAR(40)
)

CREATE TABLE Formblatt_A2 (
   Formblatt_A2_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Formblatt_A2__h_Gesamtkostvert (
   Formblatt_A2
      INTEGER NOT NULL REFERENCES Formblatt_A2,
   Gesamtkostenverteilung
      INTEGER NOT NULL REFERENCES Gesamtkostenverteilung
)

CREATE TABLE Gesamtkostenverteilung (
   Gesamtkostenverteilung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Bezeichnung_der_Kostenbeteil
      VARCHAR(100) NOT NULL,
   ist_Traeger_der_Baumassnahme
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean,
   Titel_der_Kostenbet_Bau_bisher
      VARCHAR(10) NOT NULL,
   Kostenbeteiligung_Bau_bisher
      INTEGER NOT NULL,
   Titel_der_Kostenbet_GE_bisher
      VARCHAR(10) NOT NULL,
   Kostenbeteiligung_GE_bisher
      INTEGER NOT NULL,
   Titel_der_Kostenbet_Bau
      VARCHAR(10) NOT NULL,
   Kostenbeteiligung_Bau
      INTEGER NOT NULL,
   Titel_der_Kostenbet_GE
      VARCHAR(10) NOT NULL,
   Kostenbeteiligung_GE
      INTEGER NOT NULL
)

CREATE TABLE Formblatt_A3 (
   Formblatt_A3_ID
      INTEGER NOT NULL PRIMARY KEY,
   Datum_Gesehenvermerk
      CHAR(10) NOT NULL, -- Datum
   CHECK ( Datum_Gesehenvermerk LIKE '__.__.____' ),
   Aktenzeichen_Gesehenvermerk
      VARCHAR(100) NOT NULL,
   genehmigte_Kosten_gesamt
      REAL NOT NULL, -- Groesse
   CHECK ( genehmigte_Kosten_gesamt >= 0 ),
   genehmigte_Kosten_Bund
      REAL NOT NULL, -- Groesse
   CHECK ( genehmigte_Kosten_Bund >= 0 ),
   Kosten_Teilentwurf_gesamt
      REAL NOT NULL, -- Groesse
   CHECK ( Kosten_Teilentwurf_gesamt >= 0 ),
   Kosten_Teilentwurf_Bund
      REAL NOT NULL, -- Groesse
   CHECK ( Kosten_Teilentwurf_Bund >= 0 ),
   beruecks_Kost_Strentwurf_ges
      REAL NOT NULL, -- Groesse
   CHECK ( beruecks_Kost_Strentwurf_ges >= 0 ),
   beruecks_Kost_Strentwurf_Bund
      REAL NOT NULL, -- Groesse
   CHECK ( beruecks_Kost_Strentwurf_Bund >= 0 ),
   Differenz_gesamt
      REAL NOT NULL, -- Groesse
   CHECK ( Differenz_gesamt >= 0 ),
   Differenz_Bund
      REAL NOT NULL, -- Groesse
   CHECK ( Differenz_Bund >= 0 )
)

CREATE TABLE Formblatt_A3__Bez_Streckenentw (
   Formblatt_A3
      INTEGER NOT NULL REFERENCES Formblatt_A3,
   Bezeichnung_Streckenentwurf
      VARCHAR(100) NOT NULL,
   folgt_auf_Bezeichnung_Streckenentwurf
      VARCHAR(100)
)

CREATE TABLE Formblatt_B (
   Formblatt_B_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Formblatt_B__Kost_Ingbauw_bish (
   Formblatt_B
      INTEGER NOT NULL REFERENCES Formblatt_B,
   Kosten_Ingenieurbauw_bisher
      INTEGER NOT NULL,
   folgt_auf_Kosten_Ingenieurbauw_bisher
      INTEGER
)

CREATE TABLE Formblatt_B__h_zusammg_Haupttk (
   Formblatt_B
      INTEGER NOT NULL REFERENCES Formblatt_B,
   zusammenges_Hauptteilkosten
      INTEGER NOT NULL REFERENCES zusammenges_Hauptteilkosten,
   folgt_auf_zusammenges_Hauptteilkosten
      INTEGER REFERENCES zusammenges_Hauptteilkosten
)

CREATE TABLE zusammenges_Hauptteilkosten (
   zusammenges_Hauptteilkosten_ID
      INTEGER NOT NULL PRIMARY KEY,
   Kosten_GE_des_Standes_bisher
      INTEGER NOT NULL,
   Kosten_Bau_des_Standes_bisher
      INTEGER NOT NULL
)

CREATE TABLE Formblatt_S1 (
   Formblatt_S1_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Formblatt_S1__Schaetzgrundlage (
   Formblatt_S1
      INTEGER NOT NULL REFERENCES Formblatt_S1,
   Schaetzungsgrundlage
      VARCHAR(100) NOT NULL,
   folgt_auf_Schaetzungsgrundlage
      VARCHAR(100)
)

CREATE TABLE HOAI_Daten (
   HOAI_Daten_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE HOAI_Daten__hat_HOAI_Projektd (
   HOAI_Daten
      INTEGER NOT NULL REFERENCES HOAI_Daten,
   HOAI_Projektdaten
      INTEGER NOT NULL REFERENCES HOAI_Projektdaten
)

CREATE TABLE HOAI_Daten__h_Zuordng_KBK_ING3 (
   HOAI_Daten
      INTEGER NOT NULL REFERENCES HOAI_Daten,
   Zuordnung_KBK_ING3
      INTEGER NOT NULL REFERENCES Zuordnung_KBK_ING3
)

CREATE TABLE HOAI_Daten__h_Zuordng_KBK_ING4 (
   HOAI_Daten
      INTEGER NOT NULL REFERENCES HOAI_Daten,
   Zuordnung_KBK_ING4
      INTEGER NOT NULL REFERENCES Zuordnung_KBK_ING4
)

CREATE TABLE HOAI_Projektdaten (
   HOAI_Projektdaten_ID
      INTEGER NOT NULL PRIMARY KEY,
   Vertragsnummer
      VARCHAR(255) NOT NULL,
   Anlagennummer
      VARCHAR(255) NOT NULL,
   interner_Index_HOAI_Fassung
      INTEGER NOT NULL REFERENCES Index_HOAI_Fassung,
   interner_Index_HOAI_Teil
      INTEGER NOT NULL REFERENCES Index_HOAI_Teil,
   interner_Index_HOAI_Vertrag
      INTEGER NOT NULL REFERENCES Index_HOAI_Vertrag,
   Kostenquelle
      INTEGER NOT NULL REFERENCES Kostenquelle,
   Projektbezeichnung
      VARCHAR(100) NOT NULL,
   Auftragnehmer
      VARCHAR(100) NOT NULL,
   Umsatzsteuer
      REAL NOT NULL, -- Prozent
   Minderung_nach_52_5
      INTEGER NOT NULL REFERENCES Minderung_nach_52_5_HOAI,
   Minderung_nach_52_4_2
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean,
   hat_HOAI_Honorarberechnung
      INTEGER NOT NULL REFERENCES HOAI_Honorarberechnung,
   hat_HOAI_Grundleistungen
      INTEGER NOT NULL REFERENCES HOAI_Grundleistungen,
   hat_HOAI_Sonstiges
      INTEGER NOT NULL REFERENCES HOAI_Sonstiges,
   hat_HOAI_Ermittlung_ING_10_11
      INTEGER REFERENCES HOAI_Ermittlung_ING_10_11
)

CREATE TABLE Minderung_nach_52_5_HOAI (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Minderung_nach_52_5_HOAI VALUES( 0, 'keine Abminderung' )
INSERT INTO Minderung_nach_52_5_HOAI VALUES( 1, 'Abminderung bei drei Fahrstrei-fen' )
INSERT INTO Minderung_nach_52_5_HOAI VALUES( 2, 'Abminderung bei vier Fahrstrei-fen' )
INSERT INTO Minderung_nach_52_5_HOAI VALUES( 3, 'Abminderung bei mehr als vier Fahrstreifen' )
INSERT INTO Minderung_nach_52_5_HOAI VALUES( 4, 'Abminderung bei zwei Gleisen mit gemeinsamem Planum' )

CREATE TABLE Zuordnung_KBK_ING3 (
   Zuordnung_KBK_ING3_ID
      INTEGER NOT NULL PRIMARY KEY,
   KBK_Nr_zur_Aufsumm_n_HVA_ING3
      INTEGER NOT NULL,
   Zeilennr_z_Aufsumm_im_Formular
      REAL NOT NULL, -- Groesse
   CHECK ( Zeilennr_z_Aufsumm_im_Formular >= 0 )
)

CREATE TABLE Zuordnung_KBK_ING4 (
   Zuordnung_KBK_ING4_ID
      INTEGER NOT NULL PRIMARY KEY,
   KBK_Nr_zur_Aufsumm_n_HVA_ING4
      INTEGER NOT NULL,
   Zeilennr_z_Aufsumm_im_Formular
      REAL NOT NULL, -- Groesse
   CHECK ( Zeilennr_z_Aufsumm_im_Formular >= 0 )
)

CREATE TABLE Index_HOAI_Fassung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Index_HOAI_Fassung VALUES( 1, 'HOAI Fassung gltig ab 01.01.1996' )
INSERT INTO Index_HOAI_Fassung VALUES( 2, 'HOAI Fassung gltig ab 01.01.1991' )
INSERT INTO Index_HOAI_Fassung VALUES( 3, 'HOAI Fassung gltig ab 01.04.1988' )
INSERT INTO Index_HOAI_Fassung VALUES( 10, 'HOAI Fassung gltig ab 01.01.2002' )

CREATE TABLE Index_HOAI_Teil (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Index_HOAI_Teil VALUES( 2, 'Gebude, Freianlagen und raumbildende Ausbauten' )
INSERT INTO Index_HOAI_Teil VALUES( 4, 'Gutachten und Wertermittlungen' )
INSERT INTO Index_HOAI_Teil VALUES( 5, 'Stdtebauliche Leistungen' )
INSERT INTO Index_HOAI_Teil VALUES( 6, 'Landschaftsplanerische Leistungen' )
INSERT INTO Index_HOAI_Teil VALUES( 7, 'Ingenieurbauwerke und Verkehrsanlagen' )
INSERT INTO Index_HOAI_Teil VALUES( 8, 'Tragwerksplanung' )
INSERT INTO Index_HOAI_Teil VALUES( 9, 'Technische Ausrstung' )
INSERT INTO Index_HOAI_Teil VALUES( 10, 'Thermische Bauphysik' )
INSERT INTO Index_HOAI_Teil VALUES( 11, 'Schallschutz und Raumakustik' )
INSERT INTO Index_HOAI_Teil VALUES( 12, 'Bodenmechanik' )
INSERT INTO Index_HOAI_Teil VALUES( 13, 'Vermessungstechnische Leistungen' )

CREATE TABLE Index_HOAI_Vertrag (
   Index_HOAI_Vertrag_ID
      INTEGER NOT NULL PRIMARY KEY,
   Teil
      VARCHAR(4) NOT NULL,
   Kennung
      INTEGER NOT NULL,
   Langtext
      VARCHAR(255) NOT NULL,
   UNIQUE ( Teil , Kennung ) 
)

INSERT INTO Index_HOAI_Vertrag VALUES( 'II', 1, '11' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'II', 2, '13' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'II', 3, '14a' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'IV', 1, '33' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'IV', 2, '34' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'V', 1, '38' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'V', 2, '41' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'VI', 1, '45b' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'VI', 2, '46a' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'VI', 3, '47a' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'VI', 4, '48b' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'VI', 5, '49d' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'VI', 6, '49a(FNP)' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'VI', 7, '49a(BBP)' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'VII', 1, '56.1' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'VII', 2, '56.2' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'VIII', 1, '65' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'IX', 1, '74' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'X', 1, '78' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'XI', 1, '83' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'XI', 2, '89' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'XII', 1, '94' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'XIII', 1, '97' )
INSERT INTO Index_HOAI_Vertrag VALUES( 'XIII', 2, '98' )

CREATE TABLE Kostenquelle (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Kostenquelle VALUES( 1, 'Kostenschtzung' )
INSERT INTO Kostenquelle VALUES( 2, 'Kostenberechnung' )
INSERT INTO Kostenquelle VALUES( 3, 'Kostenanschlag' )

CREATE TABLE HOAI_Honorarberechnung (
   HOAI_Honorarberechnung_ID
      INTEGER NOT NULL PRIMARY KEY,
   anrechenbare_Kosten
      REAL NOT NULL, -- Groesse
   CHECK ( anrechenbare_Kosten >= 0 ),
   Honorarzone
      INTEGER NOT NULL, -- Anzahl_einstellig
   CHECK ( ( Honorarzone >= 0 ) AND ( Honorarzone <= 9 ) ),
   Honorarsatz_in_Prozent
      REAL NOT NULL, -- Prozent
   Honorarvereinbarung
      INTEGER NOT NULL REFERENCES Honorarvereinbarung_HOAI,
   Wert_d_Aenderung_Vereinbarung
      REAL NOT NULL, -- Groesse
   CHECK ( Wert_d_Aenderung_Vereinbarung >= 0 ),
   ING_Vertragsbasis
      INTEGER NOT NULL, -- Anzahl_einstellig
   CHECK ( ( ING_Vertragsbasis >= 0 ) AND ( ING_Vertragsbasis <= 9 ) ),
   Umsatzsteuer_enthalten
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean
)

CREATE TABLE Honorarvereinbarung_HOAI (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Honorarvereinbarung_HOAI VALUES( 1, 'Tabellenhonorar bernehmen' )
INSERT INTO Honorarvereinbarung_HOAI VALUES( 2, 'Tabellenhonorar mindern' )
INSERT INTO Honorarvereinbarung_HOAI VALUES( 3, 'Honorar frei vereinbaren' )

CREATE TABLE HOAI_Grundleistungen (
   HOAI_Grundleistungen_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE HOAI_Grundl__Beauftr_GL_je_LP (
   HOAI_Grundleistungen
      INTEGER NOT NULL REFERENCES HOAI_Grundleistungen,
   Beauftragte_GL_je_Leistungsph
      REAL NOT NULL,
   folgt_auf_Beauftragte_GL_je_Leistungsph
      REAL
)

CREATE TABLE HOAI_Sonstiges (
   HOAI_Sonstiges_ID
      INTEGER NOT NULL PRIMARY KEY,
   Zuschlag_bei_Umbauten_u_Modern
      INTEGER NOT NULL REFERENCES Zuschlag_b_Umbauten_u_Modern,
   Zuschlagswert_in_Prozent
      REAL NOT NULL, -- Prozent
   besondere_Leistungen_pauschal
      REAL NOT NULL, -- Groesse
   CHECK ( besondere_Leistungen_pauschal >= 0 ),
   besondere_Leistungen_prozent
      REAL NOT NULL, -- Groesse
   CHECK ( besondere_Leistungen_prozent >= 0 ),
   Nebenkosten_pauschal
      REAL NOT NULL, -- Groesse
   CHECK ( Nebenkosten_pauschal >= 0 ),
   Nebenkosten_prozentual
      REAL NOT NULL, -- Groesse
   CHECK ( Nebenkosten_prozentual >= 0 )
)

CREATE TABLE Zuschlag_b_Umbauten_u_Modern (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Zuschlag_b_Umbauten_u_Modern VALUES( 1, 'kein Zuschlag' )
INSERT INTO Zuschlag_b_Umbauten_u_Modern VALUES( 2, 'Zuschlag nach 59' )
INSERT INTO Zuschlag_b_Umbauten_u_Modern VALUES( 3, 'Zuschlag nach 66' )

CREATE TABLE HOAI_Ermittlung_ING_10_11 (
   HOAI_Ermittlung_ING_10_11_ID
      INTEGER NOT NULL PRIMARY KEY,
   Massstab_d_LBP_Massn_n_ING_11
      INTEGER NOT NULL,
   Laenge_der_Baumassnahme
      REAL NOT NULL, -- Meter
   Breite_der_Baumassnahme
      REAL NOT NULL -- Meter
)

CREATE TABLE HOAI_Ermittl_ING_10_11__Erm_HZ (
   HOAI_Ermittlung_ING_10_11
      INTEGER NOT NULL REFERENCES HOAI_Ermittlung_ING_10_11,
   Ermittlung_der_Honorarzone
      INTEGER NOT NULL
)

CREATE TABLE HOAI_Ermittl_ING_10_11__h_Flan (
   HOAI_Ermittlung_ING_10_11
      INTEGER NOT NULL REFERENCES HOAI_Ermittlung_ING_10_11,
   Flaechenanteil_Kostendaten
      INTEGER NOT NULL REFERENCES Flaechenanteil_Kostendaten
)

CREATE TABLE Flaechenanteil_Kostendaten (
   Flaechenanteil_Kostendaten_ID
      INTEGER NOT NULL PRIMARY KEY,
   Anteil_am_Berechnungsraum_ha
      REAL NOT NULL, -- Groesse
   CHECK ( Anteil_am_Berechnungsraum_ha >= 0 ),
   Verrechnungseinheit_je_ha
      INTEGER NOT NULL
)
